#ifndef OBGTK_PROGRESS_H
#define OBGTK_PROGRESS_H 1

#include <obgtk/obgtkWidget.h>
#include <gtk/gtkprogress.h>

@interface Gtk_Progress : Gtk_Widget
{
@public
  GtkProgress *gtkprogress;
}

- castGtkProgress:(GtkProgress *) castitem;
- set_show_text:(gint) show_text;
- set_text_alignment:(gfloat) x_align :(gfloat) y_align;
- set_format_string:(gchar *) format;
- set_adjustment:(id) adjustment;
- configure:(gfloat) value :(gfloat) min :(gfloat) max;
- set_percentage:(gfloat) percentage;
- set_value:(gfloat) value;
- (gfloat) get_value;
- set_activity_mode:(guint) activity_mode;
- (gchar *) get_current_text;
- (gchar *) get_text_from_value:(gfloat) value;
- (gfloat) get_current_percentage;
- (gfloat) get_percentage_from_value:(gfloat) value;
@end

#endif /* OBGTK_PROGRESS_BAR_H */
